@@ -28,8 +28,10 @@ MainWindow::MainWindow(QWidget *parent)
       about(0),
       help(0),
       m_settings(0),
+       l_process(new QProcess(this)),
        m_process(new QProcess(this)),
-       u_process(new QProcess(this))
+       u_process(new QProcess(this)),
+       v_process(new QProcess(this))
 
 {
         //QLCD Refresh Timer
@@ -80,7 +82,12 @@ MainWindow::MainWindow(QWidget *parent)
 
       ui->setupUi(this);
 
-      setAttribute(Qt::WA_Maemo5StackedWindow);
+      //Set Window
+
+      this->setAttribute(Qt::WA_Maemo5StackedWindow);
+      this->setAttribute(Qt::WA_DeleteOnClose);
+      this->setWindowFlags(Qt::Window);
+
       about = new About(this);
       help = new Help(this);
       m_settings = new Settings(this);
@@ -141,6 +148,9 @@ MainWindow::~MainWindow()
 {
     initialseen();
 
+    if (QSettings().value("GeneralOnClose") == true)
+        l_process->startDetached("sh opt/tenminutecore/script/gen.sh");
+
     if (about) delete (about);
     if (help) delete (help);
     if (m_settings) delete (m_settings);
@@ -295,7 +305,11 @@ void MainWindow::on_preTimeout()
     refreshTimer->start();
     dTime->restart();
     timersStart();
-    m_process->start("espeak 'start_dish_exercise_for_30_seconds'");
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'start_dish_exercise_for_30_seconds'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/dish.gif"));
     ui->labelText->setText("Dish");
 }
@@ -303,9 +317,14 @@ void MainWindow::on_preTimeout()
 void MainWindow::on_aTimeout()
 {
     aTimer->stop();
-    u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
                      /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-    m_process->start("espeak 'start_sit_ups_for_30_seconds'");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'start_sit_ups_for_30_seconds'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/situp.gif"));
     ui->labelText->setText("Sit-ups");
 }
@@ -313,9 +332,14 @@ void MainWindow::on_aTimeout()
 void MainWindow::on_bTimeout()
 {
     bTimer->stop();
-    u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
                      /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-    m_process->start("espeak 'start_cycling_in_the_air_for_1_minute'");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'start_cycling_in_the_air_for_1_minute'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/cycling.gif"));
     ui->labelText->setText("Cycling in Air");
 }
@@ -323,9 +347,14 @@ void MainWindow::on_bTimeout()
 void MainWindow::on_cTimeout()
 {
     cTimer->stop();
-    u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
                      /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-    m_process->start("espeak 'start_holding_tabletop_position_for_30_seconds'");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'start_holding_tabletop_position_for_30_seconds'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/tabletopstatic.gif"));
     ui->labelText->setText("Tabletop Hold");
 }
@@ -333,9 +362,14 @@ void MainWindow::on_cTimeout()
 void MainWindow::on_dTimeout()
 {
     dTimer->stop();
-    u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
                      /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-    m_process->start("espeak 'start_side_crunches_on_right_for_30_seconds'");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'start_side_crunches_on_right_for_30_seconds'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/rs_crunch.gif"));
     ui->labelText->setText("Right Crunches");
 }
@@ -343,9 +377,14 @@ void MainWindow::on_dTimeout()
 void MainWindow::on_eTimeout()
 {
     eTimer->stop();
-    u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
                      /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-    m_process->start("espeak 'start_side_crunches_on_left_for_30_seconds'");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'start_side_crunches_on_left_for_30_seconds'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/ls_crunch.gif"));
     ui->labelText->setText("Left Crunches");
 }
@@ -353,9 +392,14 @@ void MainWindow::on_eTimeout()
 void MainWindow::on_fTimeout()
 {
     fTimer->stop();
-    u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
                      /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-    m_process->start("espeak 'start_ab_crunches_for_30_seconds'");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'start_ab_crunches_for_30_seconds'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/abcrunch.gif"));
     ui->labelText->setText("Ab Crunches");
 }
@@ -363,9 +407,14 @@ void MainWindow::on_fTimeout()
 void MainWindow::on_gTimeout()
 {
     gTimer->stop();
-    u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
                      /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-    m_process->start("espeak 'start_push_ups_for_30_seconds'");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'start_push_ups_for_30_seconds'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/pushupstatic.gif"));
     ui->labelText->setText("Push ups");
 }
@@ -373,9 +422,14 @@ void MainWindow::on_gTimeout()
 void MainWindow::on_hTimeout()
 {
     hTimer->stop();
-    u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
                      /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-    m_process->start("espeak 'start_plank_exercise_for_1_minute'");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'start_plank_exercise_for_1_minute'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/plank.gif"));
     ui->labelText->setText("Plank");
 }
@@ -383,9 +437,14 @@ void MainWindow::on_hTimeout()
 void MainWindow::on_iTimeout()
 {
     iTimer->stop();
-    u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
                      /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-    m_process->start("espeak 'start_dish_exercise_for_30_seconds'");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'start_dish_exercise_for_30_seconds'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/dish.gif"));
     ui->labelText->setText("Dish");
 }
@@ -393,9 +452,14 @@ void MainWindow::on_iTimeout()
 void MainWindow::on_jTimeout()
 {
     jTimer->stop();
-    u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
                      /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-    m_process->start("espeak 'start_double_leg_press_outs_for_30_seconds'");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'start_double_leg_press_outs_for_30_seconds'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/pressouts.gif"));
     ui->labelText->setText("Leg Pressouts");
 }
@@ -403,9 +467,14 @@ void MainWindow::on_jTimeout()
 void MainWindow::on_kTimeout()
 {
     kTimer->stop();
-    u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
                      /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-    m_process->start("espeak 'start_cycling_in_the_air_for_1_minute'");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'start_cycling_in_the_air_for_1_minute'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/cycling.gif"));
     ui->labelText->setText("Cycling in Air");
 }
@@ -413,9 +482,14 @@ void MainWindow::on_kTimeout()
 void MainWindow::on_lTimeout()
 {
     lTimer->stop();
-    u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
                      /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-    m_process->start("espeak 'start_side_crunches_on_right_for_30_seconds'");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'start_side_crunches_on_right_for_30_seconds'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/rs_crunch.gif"));
     ui->labelText->setText("Right Crunches");
 }
@@ -423,9 +497,14 @@ void MainWindow::on_lTimeout()
 void MainWindow::on_mTimeout()
 {
     mTimer->stop();
-    u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
                      /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-    m_process->start("espeak 'start_side_crunches_on_left_for_30_seconds'");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'start_side_crunches_on_left_for_30_seconds'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/ls_crunch.gif"));
     ui->labelText->setText("Left Crunches");
 }
@@ -433,9 +512,14 @@ void MainWindow::on_mTimeout()
 void MainWindow::on_nTimeout()
 {
     nTimer->stop();
-    u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
                      /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-    m_process->start("espeak 'start_dish_exercise_for_30_seconds'");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'start_dish_exercise_for_30_seconds'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/dish.gif"));
     ui->labelText->setText("Dish");
 }
@@ -443,9 +527,14 @@ void MainWindow::on_nTimeout()
 void MainWindow::on_oTimeout()
 {
     oTimer->stop();
-    u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
                      /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-    m_process->start("espeak 'start_ab_crunches_for_30_seconds'");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'start_ab_crunches_for_30_seconds'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/abcrunch.gif"));
     ui->labelText->setText("Ab Crunches");
 }
@@ -453,9 +542,14 @@ void MainWindow::on_oTimeout()
 void MainWindow::on_pTimeout()
 {
     pTimer->stop();
-    u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
-                                        /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-    m_process->start("espeak 'start_cycling_in_the_air_for_30_seconds'");
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+                      /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'start_cycling_in_the_air_for_30_seconds'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/cycling.gif"));
     ui->labelText->setText("Cycling in Air");
 }
@@ -467,9 +561,14 @@ void MainWindow::on_zTimeout()
     ui->pushButtonStart->setDisabled(false);
     ui->pushButtonStop->setDisabled(true);
     ui->lcdNumber->display("CEa5E");
-    u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
                      /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-    m_process->start("espeak 'exercise_complete'");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'exercise_complete'");
     ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/blank.gif"));
     ui->labelText->setText("-");
 }
@@ -478,7 +577,8 @@ void MainWindow::on_zTimeout()
 void MainWindow::on_pushButtonStart_clicked()
 {
     preTimer->start();
-    m_process->start("espeak 'starting_10_minute_core_workout_in_10_seconds'");
+    if (QSettings().value("SpeechAlert") == true)
+     m_process->start("espeak 'starting_10_minute_core_workout_in_10_seconds'");
     ui->lcdNumber->display("PrEParE");
     ui->pushButtonStart->setDisabled(true);
     ui->pushButtonStop->setDisabled(false);
@@ -533,11 +633,11 @@ void MainWindow::on_actionSecureDevice_triggered()
       QSettings settings;
       if ( settings.value("SecureSettingSilent","true").toString()=="true" )
       {
-          m_process->start("sh opt/tenminutecore/script/lkscsl.sh");
+          l_process->start("sh opt/tenminutecore/script/lkscsl.sh");
       }
       else
       {
-          m_process->start("sh opt/tenminutecore/script/lksc.sh");
+          l_process->start("sh opt/tenminutecore/script/lksc.sh");
       }
 }
 
