@@ -6,17 +6,19 @@
 #include <QShortcut>
 #include <QTime>
 #include <QTimer>
+#include <QSettings>
 
 Training::Training(QWidget *parent) :
     QDialog(parent),
     ui(new Ui::Training),
      t_process(new QProcess(this)),
-     u_process(new QProcess(this))
+     u_process(new QProcess(this)),
+     v_process(new QProcess(this))
 {
 
     //QLCD Refresh Timer
     refreshTimer = new QTimer(this);
-    refreshTimer->setInterval(121);
+    refreshTimer->setInterval(101);
   //Time
     dTime = new QTime;
   //Timers
@@ -112,53 +114,94 @@ void Training::on_preTimeout()
    if (!ui->pushButton30->isEnabled()) t30Timer->start();
    if (!ui->pushButton60->isEnabled()) t60Timer->start();
    if (!ui->pushButton120->isEnabled()) t120Timer->start();
-   t_process->start("aplay /usr/share/sounds/ui-confirmation_note.wav");
+   if (QSettings().value("AudioAlert") == true)
+    t_process->start("aplay /usr/share/sounds/ui-confirmation_note.wav");
 }
 
 void Training::on_t30Timeout()
 {
-   u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
-                    /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-   t_process->start("aplay /usr/share/sounds/ui-information_note.wav");
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
+    if (QSettings().value("AudioAlert") == true)
+     t_process->start("aplay /usr/share/sounds/ui-information_note.wav");
    int val = ui->lcdNumberReps->value();
-   ui->lcdNumberReps->display(val + 1);
-   if (ui->lcdNumberReps->value() == 1) ui->labelReps->setText("Rep");
-   if (ui->lcdNumberReps->value() != 1) ui->labelReps->setText("Reps");
+   int maxrep = QSettings().value("MaximumReps").toInt();
    dTime->restart();
-   t30Timer->start();
+   if (ui->lcdNumberReps->value() != maxrep)
+      {
+        t30Timer->start();
+        ui->lcdNumberReps->display(val + 1);
+        if (ui->lcdNumberReps->value() == 1) ui->labelReps->setText("Rep");
+        if (ui->lcdNumberReps->value() != 1) ui->labelReps->setText("Reps");
+      }
+   else
+      {
+        on_pushButtonTstop_clicked();
+      }
 }
 
 void Training::on_t60Timeout()
 {
-   u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
-                    /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-   t_process->start("aplay /usr/share/sounds/ui-information_note.wav");
-   int val = ui->lcdNumberReps->value();
-   ui->lcdNumberReps->display(val + 1);
-   if (ui->lcdNumberReps->value() == 1) ui->labelReps->setText("Rep");
-   if (ui->lcdNumberReps->value() != 1) ui->labelReps->setText("Reps");
-   dTime->restart();
-   t60Timer->start();
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
+    if (QSettings().value("AudioAlert") == true)
+     t_process->start("aplay /usr/share/sounds/ui-information_note.wav");
+    int val = ui->lcdNumberReps->value();
+    int maxrep = QSettings().value("MaximumReps").toInt();
+    dTime->restart();
+    if (ui->lcdNumberReps->value() != maxrep)
+       {
+         t30Timer->start();
+         ui->lcdNumberReps->display(val + 1);
+         if (ui->lcdNumberReps->value() == 1) ui->labelReps->setText("Rep");
+         if (ui->lcdNumberReps->value() != 1) ui->labelReps->setText("Reps");
+       }
+    else
+       {
+         on_pushButtonTstop_clicked();
+       }
 }
 
 void Training::on_t120Timeout()
 {
-   u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
-                    /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
-   t_process->start("aplay /usr/share/sounds/ui-information_note.wav");
-   int val = ui->lcdNumberReps->value();
-   ui->lcdNumberReps->display(val + 1);
-   if (ui->lcdNumberReps->value() == 1) ui->labelReps->setText("Rep");
-   if (ui->lcdNumberReps->value() != 1) ui->labelReps->setText("Reps");
-   dTime->restart();
-   t120Timer->start();
+    if (QSettings().value("VibrationAlert") == true)
+     v_process->start("dbus-send --system --print-reply --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_start_manual_vibration int32:250 int32:700");
+    if (QSettings().value("WakeScreen") == true)
+     u_process->start("dbus-send --print-reply --system --dest=com.nokia.mce\
+                     /com/nokia/mce/request com.nokia.mce.request.req_tklock_mode_change string:unlocked");
+    if (QSettings().value("AudioAlert") == true)
+     t_process->start("aplay /usr/share/sounds/ui-information_note.wav");
+    int val = ui->lcdNumberReps->value();
+    int maxrep = QSettings().value("MaximumReps").toInt();
+    dTime->restart();
+    if (ui->lcdNumberReps->value() != maxrep)
+       {
+          t30Timer->start();
+          ui->lcdNumberReps->display(val + 1);
+          if (ui->lcdNumberReps->value() == 1) ui->labelReps->setText("Rep");
+          if (ui->lcdNumberReps->value() != 1) ui->labelReps->setText("Reps");
+       }
+    else
+       {
+          on_pushButtonTstop_clicked();
+       }
 }
 
 //pushButtons
 void Training::on_pushButtonTstart_clicked()
 {
    preTimer->start();
-   t_process->start("aplay /usr/share/sounds/ui-information_note.wav");
+   if (QSettings().value("AudioAlert") == true)
+    t_process->start("aplay /usr/share/sounds/ui-information_note.wav");
    ui->lcdNumber->display("PrEParE");
    ui->pushButtonTstart->setDisabled(true);
    ui->pushButtonTstop->setDisabled(false);
